<?php

class InsuranceController extends AdmController {

    protected function beforeAction($action) {
        if (parent::beforeAction($action)) {
            Yii::app()->session['sidebar_active'] = 'insurance';
            return true;
        }
        return false;
    }

    public function actionIndex() {
        $datetype = Yii::app()->session['insurance_datetype'];
        $datef = Yii::app()->session['insurance_datef'];
        $datee = Yii::app()->session['insurance_datee'];
        $txtsearch = Yii::app()->session['insurance_txtsearch'];

        $grids = $this->getGridData($txtsearch, $datef, $datee, $datetype);
        $this->render('index', array('grids' => $grids,
            'txtsearch' => $txtsearch,
            'datef' => $datef, 'datee' => $datee,
            'datetype' => $datetype));
    }

    public function actionAjaxList() {
        $offset = (isset($_GET['page'])) ? $_GET['page'] : 0;

        Yii::app()->session['insurance_datetype'] = $_POST['datetype'];
        Yii::app()->session['insurance_datef'] = $_POST['datef'];
        Yii::app()->session['insurance_datee'] = $_POST['datee'];
        Yii::app()->session['insurance_txtsearch'] = $_POST['txtsearch'];

        $grids = $this->getGridData($_POST['txtsearch'], $_POST['datef'], $_POST['datee'], $_POST['datetype'], $offset);
        $this->renderPartial('_gridview', array('grids' => $grids));
    }

    public function getGridData($txtsearch = '', $datef = '', $datee = '', $datetype = '0', $offset = 0) {
        $date_field = 'datefix';
        switch ($datetype) {
            case '1':
                //วันที่เอกสาร
                $date_field = 'docdate';
                break;
            case '2':
                //วันที่ต่อกรมธรรม์
                $date_field = 'datef';
                break;
            case '3':
                //วันที่หมดอายุ
                $date_field = 'datee';
                break;
        }

        $sql = "SELECT tb_insurance.id, tb_insurance.docno, tb_insurance.docdate, tb_insurance.datef, tb_insurance.datee,";
        $sql.= " tb_car.code as car_code, tb_insurance.price FROM tb_insurance ";
        $sql.= " LEFT JOIN tb_car ON tb_insurance.car_id = tb_car.id";
        $sql.= " Where (tb_car.code LIKE '%$txtsearch%' OR tb_insurance.docno LIKE '%$txtsearch%')";

        if ($datetype != '0') {
            if ($datef != '' && $datee != '') {
                $sql.= " AND (tb_insurance.$date_field >= '" . MyDate::dateToMysql($datef) . "'";
                $sql.= " AND tb_insurance.$date_field <= '" . MyDate::dateToMysql($datee) . "')";
            } else if ($datef != '' && $datee == '') {
                //กรอกแต่วันที่เริ่ม
                $sql.= " AND (tb_insurance.$date_field >= '" . MyDate::dateToMysql($datef) . "')";
            } else if ($datef == '' && $datee != '') {
                //กรอกแต่วันที่สิ้นสุด
                $sql.= " AND (tb_insurance.$date_field <= '" . MyDate::dateToMysql($datee) . "')";
            }
        }

        $count = Yii::app()->db->createCommand($sql)->execute();

        $pages = new CPagination($count);
        $pages->route = 'ajaxList';

        $pageLimit = Yii::app()->params['pageSize'];

        if ($offset > 0) {
            $recordStart = ($offset * $pageLimit) - $pageLimit;
        } else {
            $recordStart = 0;
        }

        $pages->pageSize = $pageLimit;
        $sql.= " Order By tb_insurance.docno asc";
        $sql.= " limit $recordStart,$pageLimit";
        $models = Yii::app()->db->createCommand($sql)->queryAll();
        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    public function actionCreate() {
        $model = new Insurance;
        $model->docno = Docprefix::model()->getDocrun(4);
        $model->docdate = date('Y-m-d');
        $model->datef = date('Y-m-d');
        $model->datee = date('Y-m-d', strtotime('+1 years'));

        $user = User::model()->findByPk(Yii::app()->user->id);
        $model->person_name = $user->title . $user->firstname . " " . $user->surname;
        $this->render('form', array('model' => $model));
    }

    public function actionAjaxValidate() {
        $model = new Insurance;
        $data = $model->checkDuplicate($_POST['id'], $_POST['docno']);
        echo CJSON::encode($data);
    }

    public function actionUpdate() {
         $id = (isset($_GET['id'])) ? (int)$_GET['id'] : '';
        $model = Insurance::model()->findByPk($id);

        if (isset($_POST['Insurance'])) {
            if ($_POST['id'] == '') {
                $model = new Insurance;
                $model->date_create = date('Y-m-d H:i:s');
                $model->date_edit = date('Y-m-d H:i:s');
            } else {
                //submit มาจาก form
                $model = Insurance::model()->findByPk($_POST['id']);
                $model->date_edit = date('Y-m-d H:i:s');
            }

            $model->attributes = $_POST['Insurance'];
            $model->docdate = MyDate::dateToMySql($model->docdate);
            $model->datef = MyDate::dateToMySql($model->datef);
            $model->datee = MyDate::dateToMySql($model->datee);
            $model->user_save_id = Yii::app()->user->id;

            if ($model->save()) {                
                $car = Car::model()->findByPk($model->car_id);

                $carUpdate = false;
                if (isset($car->id)) {
                    $carUpdate = true;
                    $carId = $model->car_id;
                    $sql = "select * from tb_insurance where car_id = '$carId' order by datee desc limit 1";
                    $carInsurance = Yii::app()->db->createCommand($sql)->queryRow();
                    if (isset($carInsurance['id'])) {
                        $car->date_f_insure = $carInsurance['datef'];
                        $car->date_e_insure = $carInsurance['datee'];
                        if (!$car->save())
                            $carUpdate = false;
                    } else {
                        $carUpdate = false;
                    }
                }

                if ($carUpdate) {
                    Yii::app()->user->setFlash('success', 'บันทึกข้อมูลเรียบร้อย');
                    $this->redirect(array('update', 'id' => $model->id));
                } else {
                    Yii::app()->user->setFlash('success', 'บันทึกการต่อทะเบียนสำเร็จ แต่ไม่สามารถอัพเดทข้อมูลกลับไปที่ข้อมูลรถได้ ให้ลองลบรายการนี้แล้วทำรายการใหม่');
                    $this->redirect(array('update', 'id' => $model->id));
                }
            } else {
                Yii::app()->user->setFlash('success', 'ไม่สามารถบันทึกข้อมูลได้เนื่องจาก ' . $model->getErrors());
                $this->redirect(array('update', 'id' => $model->id));
            }
        }
        $this->render('form', array('model' => $model));
    }

    public function actionAjaxDelete() {
        $msg = '0';

        $id = (int) $_POST['id'];
        $row = Insurance::model()->findByPk($id);
        $row->delete();
        $data['msg'] = $msg;
        echo CJSON::encode($data);
    }

}
