<?php

class QueryController extends Controller {

    protected function beforeAction($action) {
        if (parent::beforeAction($action)) {
            Yii::app()->session['sidebar_active'] = 'query';
            return true;
        }
        return false;
    }

    public function actionIndex() {
        if (!isset(Yii::app()->session['query_txtsearch'])) {
            $start_date = date("Y-m") . "-01";
            $end_date = date("Y-m-t", strtotime($start_date));
            $txtsearch = '';

            $start_date = MyDate::dateToText($start_date);
            $end_date = MyDate::dateToText($end_date);
        } else {
            $txtsearch = Yii::app()->session['query_txtsearch'];
            $start_date = Yii::app()->session['query_start_date'];
            $end_date = Yii::app()->session['query_end_date'];
        }

        $grids = $this->getGridData('', $start_date, $end_date);
        $this->render('index', array('grids' => $grids,
            'txtsearch' => $txtsearch,
            'start_date' => $start_date,
            'end_date' => $end_date));
    }

    public function actionAjaxList() {
        $offset = (isset($_GET['page'])) ? $_GET['page'] : 0;

        Yii::app()->session['query_txtsearch'] = $_POST['txtsearch'];
        Yii::app()->session['query_start_date'] = $_POST['start_date'];
        Yii::app()->session['query_end_date'] = $_POST['end_date'];

        $grids = $this->getGridData($_POST['txtsearch'], $_POST['start_date'], $_POST['end_date'], $offset);
        $this->renderPartial('_gridview', array('grids' => $grids));
    }

    public function getGridData($txtsearch = '', $start_date = '', $end_date = '', $offset = 0) {
        $sql = "SELECT tb_booking.id, tb_booking.docno, tb_booking.docdate, tb_booking.doctime,";
        $sql.= " tb_booking.start_date, tb_booking.end_date, tb_booking.status,";
        $sql.= " tb_car.code as car_code, tb_booking.person_name, ";
        $sql.= " tb_booking.working, tb_booking.status FROM tb_booking ";
        $sql.= " LEFT JOIN tb_car ON tb_booking.car_id = tb_car.id";
        $sql.= " Where (tb_car.code LIKE '%$txtsearch%')";
        //$sql.= " AND (tb_car.code LIKE '%$txtsearch%')";
        $sql.= " AND (tb_booking.status < '9')";

        $start_date = MyDate::dateToMysql($start_date);
        $end_date = MyDate::dateToMysql($end_date);
        if ($start_date == '') {
            $start_date = '0000-00-00';
        }
        if ($end_date == '') {
            $end_date = '3000-01-01';
        }

        $sql.= " AND (";
        $sql.= " (date(tb_booking.start_date) between '$start_date' AND '$end_date')";
        $sql.= " OR (date(tb_booking.end_date) between '$start_date' AND '$end_date')";
        $sql.= " OR ('$start_date' between date(tb_booking.start_date) AND date(tb_booking.end_date))";
        $sql.= " OR ('$end_date' between date(tb_booking.start_date) AND date(tb_booking.end_date))";
        $sql.= ")";

        $count = Yii::app()->db->createCommand($sql)->execute();

        $pages = new CPagination($count);
        $pages->route = 'ajaxList';

        $pageLimit = Yii::app()->params['pageSize'];

        if ($offset > 0) {
            $recordStart = ($offset * $pageLimit) - $pageLimit;
        } else {
            $recordStart = 0;
        }

        $pages->pageSize = $pageLimit;
        $sql.= " Order By tb_booking.start_date, tb_booking.end_date, tb_car.code";
        $sql.= " limit $recordStart,$pageLimit";
        $models = Yii::app()->db->createCommand($sql)->queryAll();
        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    public function actionDetail() {
        $id = (isset($_GET['id'])) ? (int) $_GET['id'] : '';
        $model = Booking::model()->findByPk($id);
        $this->render('detail', array('model' => $model));
    }

    public function actionCar() {
        Yii::app()->session['sidebar_active'] = 'cardetail';
        $txtfield = Yii::app()->session['querycar_txtfield'];
        $txtsearch = Yii::app()->session['querycar_txtsearch'];

        $grids = $this->getGridDataCar($txtsearch, $txtfield);
        $this->render('car', array('grids' => $grids,
            'txtsearch' => $txtsearch, 'txtfield' => $txtfield));
    }

    public function actionAjaxListCar() {
        $offset = (isset($_GET['page'])) ? $_GET['page'] : 0;

        Yii::app()->session['querycar_txtfield'] = $_POST['txtfield'];
        Yii::app()->session['querycar_txtsearch'] = $_POST['txtsearch'];

        $grids = $this->getGridDataCar($_POST['txtsearch'], $_POST['txtfield'], $offset);
        $this->renderPartial('_gridview_car', array('grids' => $grids));
    }

    public function getGridDataCar($txtsearch = '', $txtfield = '', $offset = 0) {
        $sql = "SELECT tb_car.id, tb_car.`code`, tb_brand.`name` as brand_name, tb_car.model, ";
        $sql.= " tb_cartype.`name` as cartype_name, tb_oil.name as oil_name FROM tb_car ";
        $sql.= " LEFT JOIN tb_cartype ON tb_car.cartype_id = tb_cartype.id";
        $sql.= " LEFT JOIN tb_brand ON tb_car.brand_id = tb_brand.id";
        $sql.= " LEFT JOIN tb_oil on tb_car.oil_id = tb_oil.id";

        if ($txtfield == '') {
            $sql.= " Where (tb_car.`code` LIKE '%$txtsearch%' or tb_brand.`name` LIKE '%$txtsearch%' or tb_car.model LIKE '%$txtsearch%' ";
            $sql.= " or tb_cartype.`name` LIKE '%$txtsearch%')";
        } else {
            $sql.= " Where ($txtfield LIKE '%$txtsearch%')";
        }

        $count = Yii::app()->db->createCommand($sql)->execute();

        $pages = new CPagination($count);
        $pages->route = 'ajaxListCar';

        $pageLimit = Yii::app()->params['pageSize'];

        if ($offset > 0) {
            $recordStart = ($offset * $pageLimit) - $pageLimit;
        } else {
            $recordStart = 0;
        }

        $pages->pageSize = $pageLimit;
        $sql.= " Order By tb_car.code asc";
        $sql.= " limit $recordStart,$pageLimit";
        $models = Yii::app()->db->createCommand($sql)->queryAll();
        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    public function actionCardetail() {
        Yii::app()->session['sidebar_active'] = 'cardetail';
        $id = (isset($_GET['id'])) ? (int) $_GET['id'] : '';
        $model = Car::model()->findByPk($id);
        $this->render('car_detail', array('model' => $model));
    }

}
